from system.clips import clips, copy, paste

from system.user import userfind, whoami

from system.xlib import xinput, xnotify, xyesno, xmsgok

from system.which import which

from system.fileage import fileage

from system.uptime import wittime



#!/usr/bin/env python3
# -*- encoding: utf-8 -*-
#
# This file is free software by d0n <d0n@janeiskla.de>
#
# You can redistribute it and/or modify it under the terms of the GNU -
# Lesser General Public License as published by the Free Software Foundation
#
# This is distributed in the hope that it will be useful somehow.
#
# !WITHOUT ANY WARRANTY!
#
# Without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
# details.
#
"""linux x-notification library"""
from sys import stderr
from inspect import stack
try:
	import gi
	gi.require_version('Notify', '0.7')
	from gi.repository import Notify as xnote
except (AttributeError, ImportError) as err:
	print(err, file=stderr)
	def xnotify(*args): return

def xnotify(msg, name=stack()[1][3], wait=3):
	xnote.init(str(name))
	note = xnote.Notification.new(msg)
	wait = int(wait)*600
	note.set_timeout(wait)
	try:
		note.show()
	except RuntimeError:
		pass



"""init of colortext just import all usability functions"""
from colortext.colortext import \
    blu, cya, gre, grn, red, vio, whi, yel, \
    bblu, bcya, bgre, bgrn, bred, bvio, bwhi, byel, \
    tabd, tabl, tabs, abort, error, fatal



#!/usr/bin/env python3
# -*- encoding: utf-8 -*-
#
# This file is free software by d0n <d0n@janeiskla.de>
#
# You can redistribute it and/or modify it under the terms of the GNU -
# Lesser General Public License as published by the Free Software Foundation
#
# This is distributed in the hope that it will be useful somehow.
#
# !WITHOUT ANY WARRANTY!
#
# Without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
# details.

try:
	from tkinter import StringVar, Button, Entry, Frame, Label, Tk
except ImportError:
	from Tkinter import StringVar, Button, Entry, Frame, Label, Tk

def xmsgok(message="press any key to continue"):
	"""gui representing function"""
	class XMessage(Frame):
		"""password clipping class for tkinter.Frame"""
		def __init__(self, master):
			Frame.__init__(self, master)
			self.pack()
			self.inputwindow()
		def _exit(self, _=None):
			"""just exit (for ESC mainly)"""
			self.quit()
		def inputwindow(self):
			"""password input window creator"""
			self.lbl = Label(self, text=message)
			self.lbl.pack()
			self.bind("<Key>", self._exit)
			self.pack()
			self.focus_set()
			self.ok = Button(self)
			self.ok["text"] = "ok"
			self.ok["command"] = self._exit
			self.ok.pack()
	# instanciate Tk and create window
	root = Tk()
	xms = XMessage(root)
	xms.lift()
	xms.mainloop()
	root.destroy()
